---
template: mainpanel
source_form: markdown
name: Trello Cardlist Backlog: Proposed Next
updated: October 2016
title: Trello Cardlist Backlog: Proposed Next
---
### Backlog: Proposed Next

* 196\. Batch Compiler
* 59\. Start thoughts on pyxie-web #reflect #website
* 195\. Functionality of bin/pyxie-dev is in core, not a script
* 3\.5 Analysis code looks for an arduino profile file describing c-types appropriately.
* 3\.6 arduino profile file is propogated with something relating to core functions that read values, to avoid forcing types "manually"
* 213\. v0 no funcs Playful Puppy code analyses
* 214\. v0 no funcs Playful Puppy code generates code
* 215\. v0 no funcs Playful Puppy code compiles, and runs on device correctly
* 221\. Initial spike support for function definitions. (no args, no return values)
* 223\. Spike support for functions with basic arguments.
* 222\. Spike support for functions which use local variables
